@@ -6,6 +6,7 @@ from tg import url, request
 from tg.i18n import ugettext as _
 from webhelpers import date, feedgenerator, html, number, misc, text
 from smallpress import model
+from tgext.pluggable import app_model
 
 def bold(text):
     return html.literal('<strong>%s</strong>' % text)
@@ -34,7 +35,7 @@ def link_buttons(entity, *buttons):
     return html.literal(btns_html)
 
 def comma_separated_tags(entity):
-    return ', '.join((t[0] for t in model.Tagging.tag_cloud_for_object(entity)))
+    return ', '.join((t[0] for t in app_model.Tagging.tag_cloud_for_object(entity)))
 
 def format_published(entity):
     if entity.published:
