@@ -35,6 +35,7 @@ except ImportError:
     sqla_events = False
 
 AttachmentType = tg.config.get('_smallpress',{}).get('attachment_type', AttachedFile)
+ENABLE_ARTICLES_CACHE = tg.config.get('_smallpress',{}).get('enable_cache', False)
 
 class Blog(DeclarativeBase):
     __tablename__ = 'smallpress_blogs'
@@ -62,7 +63,7 @@ class Article(DeclarativeBase):
     blog_id = Column(Integer, ForeignKey(primary_key(Blog)), nullable=True, index=True)
     blog = relation(Blog, backref=backref('articles'), lazy='joined')
 
-    publish_date = Column(DateTime, nullable=False, default=datetime.now)
+    publish_date = Column(DateTime, nullable=False, default=datetime.now, index=True)
     update_date = Column(DateTime, nullable=False, default=datetime.now)
     description = Column(Unicode(150), nullable=False, default=u'Empty article, edit or delete this')
     content = Column(Unicode(32000), nullable=False, default=u'')
@@ -149,6 +150,19 @@ class Article(DeclarativeBase):
 
         return identity['user'] == self.author
 
+    @property
+    def caching_options(self):
+        if not ENABLE_ARTICLES_CACHE:
+            return dict()
+
+        userid = request.identity['user'].user_id if request.identity else 'None'
+        try:
+            return dict(key='%s-%s-%s-%s' % (userid, 'smallpress-article',
+                                             self.uid, self.update_date.strftime('%Y-%m-%d-%H-%M-%S')),
+                                             expire=14400, type="memory")
+        except (IndexError, ValueError):
+            return dict()
+
 if whoosh_enabled and sqla_events:
     event.listen(Article, 'after_update', Article.after_update)
     event.listen(Article, 'after_insert', Article.after_insert)
